@@ -9,4 +9,4 @@ def test_wrap():
     container = SqlContainer(text)
     _container = container.wrap(wrapper_text)
     assert container is _container
-    assert str(container) == '(\n  abc\n) xyz'
+    assert str(container) == f'(\n  {text}\n) {wrapper_text}'
